% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{cm_boundary}
\alias{cm_boundary}
\title{Normal mixture (CM) boundary}
\usage{
cm_boundary(v, alpha, rho)
}
\arguments{
\item{v}{Numeric vector >= 0. Intrinsic time values (V_t or t).}

\item{alpha}{Numeric in (0,1). ONE-SIDED significance level.}

\item{rho}{Numeric > 0. Tuning parameter. Obtain via rho_from_vopt().}
}
\value{
Numeric vector of boundary values (cumulative-sum scale, before /t).
}
\description{
Normal mixture (CM) boundary
}
\examples{
  rho <- rho_from_vopt(v_opt = 10, alpha = 0.025)
  u   <- cm_boundary(v = 1:500, alpha = 0.025, rho = rho)

}
\seealso{
\code{\link[=rho_from_vopt]{rho_from_vopt()}} to compute \code{rho} from a target \code{v_opt}.
}
