% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/etests.R
\name{eprocess_rejections}
\alias{eprocess_rejections}
\title{Determine rejection times for an e-process output}
\usage{
eprocess_rejections(ep, alpha = 0.05)
}
\arguments{
\item{ep}{data.frame. Output of eprocess().}

\item{alpha}{Numeric. Significance level. Threshold is 2/alpha.}
}
\value{
Named list with elements:
\itemize{
\item \code{threshold} — rejection threshold (\code{2 / alpha}).
\item \code{tau_pq} — first \code{t} where \code{e_pq >= threshold} (\code{NA} if never crossed).
\item \code{tau_qp} — first \code{t} where \code{e_qp >= threshold} (\code{NA} if never crossed).
\item \code{reject_pq} — logical: was \eqn{H_0^w(p,q)} ever rejected?
\item \code{reject_qp} — logical: was \eqn{H_0^w(q,p)} ever rejected?
}
}
\description{
Determine rejection times for an e-process output
}
\examples{
scores1 <- c(-0.04, -0.09, -0.01, -0.16)
scores2 <- c(-0.09, -0.16, -0.04, -0.25)
ep <- eprocess(scores1, scores2, alpha = 0.05)
eprocess_rejections(ep, alpha = 0.05)

}
